% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Ost.bestparams.R
\name{Ost.bestparams}
\alias{Ost.bestparams}
\title{Obtain set of best params from Ostrich data}
\usage{
Ost.bestparams(Ost.data = NA, best.num = 0.1, num.metrics = NA,
  remove.run = T)
}
\arguments{
\item{Ost.data}{data object from Ost.read function (optional)}

\item{best.num}{indicates the method for selecting top best runs}

\item{num.metrics}{number of fit metrics used in Ostrich; will remove the
metrics if supplied}

\item{remove.run}{boolean for removing the 'Run' column in returned data}
}
\value{
\item{Ost.bestruns}{Ostrich trials with the top best objective
function}
}
\description{
Ost.bestparams is used to extract the best trials from the Ostrich data,
based on the objective function value.
}
\details{
Ost.bestparams extracts the runs with the best objective function value from
the data supplied. This function may be useful in comparing the parameters
of an optimization trial to check for equifinality in models.

Ost.data is the data object created from Ost.read. If not supplied, this
function will look for the OstModel0.txt file in the current directory to
read data from.

best.num indicates the method used to get the top best trials. If best.num
is a double less than 1, this function will return the top percentage of
best trials. If best.num is an integer, the function will return the top X
trials in the file, where X=best.num.

num.metrics refers to the number of fit metrics used in the Ostrich
calibration, of which there should be at least one. If this value is
supplied, the function will remove the metric columns from the returned
data.

remove.run is a boolean to indicate whether the run column should be
removed.
}
\examples{
# warning: example not run, sample example for associated files only
\dontrun{

# locate sample OstModel0.txt file in RavenR package
ff <- system.file("extdata","OstModel0.txt", package="RavenR")

# read in file
mydata <- Ost.read(ff)

# top 30 percent of runs, no removal of metrics
mybest <- Ost.bestparams(mydata,best.num=0.3)
head(mybest)

# minimalist function run (requires OstModel0.txt in current directory)
mybest <- Ost.bestparams(mydata)
head(mybest)
}

}
\seealso{
\code{\link{Ost.read}} for reading in Ostrich files

\code{\link{Ost.plot}} for creating various plots with Ostrich data

\code{\link{Ost.params.compare}} for comparing parameters between multiple
Ostrich calibration jobs

Download Ostrich at
\href{http://www.eng.buffalo.edu/~lsmatott/Ostrich/OstrichMain.html}{Shawn
Matott's web page}

See also \href{http://www.civil.uwaterloo.ca/jrcraig/}{James R.
Craig's research page} for other software downloads, including the
\href{http://www.civil.uwaterloo.ca/jrcraig/Raven/Main.html}{Raven page}
}
\keyword{Ostrich}
\keyword{best}
\keyword{calibration}
\keyword{parameter}
